@@ -152,7 +152,7 @@ contact_list_view_is_visible_contact (EmpathyContactListView *self,
 	g_assert (live != NULL);
 
 	/* check alias name */
-	str = empathy_contact_get_name (contact);
+	str = empathy_contact_get_alias (contact);
 	if (empathy_live_search_match (live, str))
 		return TRUE;
 
@@ -1276,6 +1276,28 @@ contact_list_view_search_activate_cb (GtkWidget *search,
 	}
 }
 
+static gboolean
+contact_list_view_search_key_navigation_cb (GtkWidget *search,
+					    GdkEvent *event,
+					    EmpathyContactListView *view)
+{
+	GdkEventKey *eventkey = ((GdkEventKey *) event);
+	gboolean ret = FALSE;
+
+	if (eventkey->keyval == GDK_Up || eventkey->keyval == GDK_Down) {
+		GdkEvent *new_event;
+
+		new_event = gdk_event_copy (event);
+		gtk_widget_grab_focus (GTK_WIDGET (view));
+		ret = gtk_widget_event (GTK_WIDGET (view), new_event);
+		gtk_widget_grab_focus (search);
+
+		gdk_event_free (new_event);
+	}
+
+	return ret;
+}
+
 static void
 contact_list_view_search_hide_cb (EmpathyLiveSearch      *search,
 				  EmpathyContactListView *view)
@@ -2063,7 +2085,7 @@ contact_list_view_remove_activate_cb (GtkMenuItem            *menuitem,
 
 		parent = empathy_get_toplevel_window (GTK_WIDGET (view));
 		text = g_strdup_printf (_("Do you really want to remove the contact '%s'?"),
-					empathy_contact_get_name (contact));
+					empathy_contact_get_alias (contact));
 		if (contact_list_view_remove_dialog_show (parent, _("Removing contact"), text)) {
 			EmpathyContactList *list;
 
@@ -2143,6 +2165,9 @@ empathy_contact_list_view_set_live_search (EmpathyContactListView *view,
 		g_signal_handlers_disconnect_by_func (priv->search_widget,
 			contact_list_view_search_activate_cb,
 			view);
+		g_signal_handlers_disconnect_by_func (priv->search_widget,
+			contact_list_view_search_key_navigation_cb,
+			view);
 		g_signal_handlers_disconnect_by_func (priv->search_widget,
 			contact_list_view_search_hide_cb,
 			view);
@@ -2167,6 +2192,9 @@ empathy_contact_list_view_set_live_search (EmpathyContactListView *view,
 		g_signal_connect (priv->search_widget, "activate",
 			G_CALLBACK (contact_list_view_search_activate_cb),
 			view);
+		g_signal_connect (priv->search_widget, "key-navigation",
+			G_CALLBACK (contact_list_view_search_key_navigation_cb),
+			view);
 		g_signal_connect (priv->search_widget, "hide",
 			G_CALLBACK (contact_list_view_search_hide_cb),
 			view);
