@@ -245,10 +245,8 @@ static void
 empathy_contact_audio_call_menu_item_activated (GtkMenuItem *item,
 	EmpathyContact *contact)
 {
-	EmpathyCallFactory *factory;
 
-	factory = empathy_call_factory_get ();
-	empathy_call_factory_new_call_with_streams (factory, contact, TRUE, FALSE,
+	empathy_call_factory_new_call_with_streams (contact, TRUE, FALSE,
 		gtk_get_current_event_time (), NULL, NULL);
 }
 
@@ -278,10 +276,7 @@ static void
 empathy_contact_video_call_menu_item_activated (GtkMenuItem *item,
 	EmpathyContact *contact)
 {
-	EmpathyCallFactory *factory;
-
-	factory = empathy_call_factory_get ();
-	empathy_call_factory_new_call_with_streams (factory, contact, TRUE, TRUE,
+	empathy_call_factory_new_call_with_streams (contact, TRUE, TRUE,
 		gtk_get_current_event_time (), NULL, NULL);
 }
 
