@@ -34,6 +34,7 @@
 
 #include <telepathy-glib/account.h>
 #include <telepathy-glib/util.h>
+#include <telepathy-glib/interfaces.h>
 
 #include <libempathy/empathy-tp-contact-factory.h>
 #include <libempathy/empathy-contact-manager.h>
@@ -77,7 +78,6 @@
 
 typedef struct
 {
-  EmpathyTpContactFactory *factory;
   EmpathyContactManager *manager;
   EmpathyContact *contact;
   EmpathyContactWidgetFlags flags;
@@ -95,7 +95,6 @@ typedef struct
   GtkWidget *widget_id;
   GtkWidget *widget_alias;
   GtkWidget *label_alias;
-  GtkWidget *entry_alias;
   GtkWidget *hbox_presence;
   GtkWidget *image_state;
   GtkWidget *label_status;
@@ -124,6 +123,9 @@ typedef struct
   GtkWidget *vbox_details;
   GtkWidget *table_details;
   GtkWidget *hbox_details_requested;
+  GtkWidget *spinner_details;
+  GList *details_to_set;
+  GCancellable *details_cancellable;
 
   /* Client */
   GtkWidget *vbox_client;
@@ -147,17 +149,391 @@ enum
   COL_COUNT
 };
 
+static void
+contact_widget_save (EmpathyContactWidget *information)
+{
+  TpConnection *connection;
+  GList *l, *next;
+
+  connection = empathy_contact_get_connection (information->contact);
+
+  /* Remove empty fields */
+  for (l = information->details_to_set; l != NULL; l = next)
+    {
+      TpContactInfoField *field = l->data;
+
+      next = l->next;
+      if (field->field_value == NULL || EMP_STR_EMPTY (field->field_value[0]))
+        {
+          DEBUG ("Drop empty field: %s", field->field_name);
+          tp_contact_info_field_free (field);
+          information->details_to_set =
+              g_list_delete_link (information->details_to_set, l);
+        }
+    }
+
+  if (information->details_to_set != NULL)
+    {
+      tp_connection_set_contact_info_async (connection,
+          information->details_to_set, NULL, NULL);
+      tp_contact_info_list_free (information->details_to_set);
+      information->details_to_set = NULL;
+    }
+}
+
 static void
 contact_widget_details_setup (EmpathyContactWidget *information)
 {
-  /* FIXME: Needs new telepathy spec */
   gtk_widget_hide (information->vbox_details);
+
+  information->spinner_details = gtk_spinner_new ();
+  gtk_box_pack_end (GTK_BOX (information->hbox_details_requested),
+      information->spinner_details, TRUE, TRUE, 0);
+  gtk_widget_show (information->spinner_details);
+}
+
+static void
+contact_widget_details_changed_cb (GtkEntry *entry,
+    TpContactInfoField *field)
+{
+  const gchar *strv[] = { NULL, NULL };
+
+  strv[0] = gtk_entry_get_text (entry);
+
+  if (field->field_value != NULL)
+    g_strfreev (field->field_value);
+  field->field_value = g_strdupv ((GStrv) strv);
+}
+
+static void contact_widget_details_notify_cb (EmpathyContactWidget *information);
+
+typedef struct
+{
+  const gchar *field_name;
+  const gchar *title;
+  gboolean linkify;
+} InfoFieldData;
+
+static InfoFieldData info_field_datas[] =
+{
+  { "fn",    N_("Full name:"),      FALSE },
+  { "tel",   N_("Phone number:"),   FALSE },
+  { "email", N_("E-mail address:"), TRUE },
+  { "url",   N_("Website:"),        TRUE },
+  { "bday",  N_("Birthday:"),       FALSE },
+  { NULL, NULL }
+};
+
+static InfoFieldData *
+find_info_field_data (const gchar *field_name)
+{
+  guint i;
+
+  for (i = 0; info_field_datas[i].field_name != NULL; i++)
+    {
+      if (!tp_strdiff (info_field_datas[i].field_name, field_name))
+        return info_field_datas + i;
+    }
+  return NULL;
+}
+
+static gint
+contact_info_field_name_cmp (const gchar *name1,
+    const gchar *name2)
+{
+  guint i;
+
+  if (!tp_strdiff (name1, name2))
+    return 0;
+
+  /* We use the order of info_field_datas */
+  for (i = 0; info_field_datas[i].field_name != NULL; i++)
+    {
+      if (!tp_strdiff (info_field_datas[i].field_name, name1))
+        return -1;
+      if (!tp_strdiff (info_field_datas[i].field_name, name2))
+        return +1;
+    }
+
+  return g_strcmp0 (name1, name2);
+}
+
+static gint
+contact_info_field_cmp (TpContactInfoField *field1,
+    TpContactInfoField *field2)
+{
+  return contact_info_field_name_cmp (field1->field_name, field2->field_name);
+}
+
+static gint
+contact_info_field_spec_cmp (TpContactInfoFieldSpec *spec1,
+    TpContactInfoFieldSpec *spec2)
+{
+  return contact_info_field_name_cmp (spec1->name, spec2->name);
+}
+
+static guint
+contact_widget_details_update_edit (EmpathyContactWidget *information)
+{
+  TpContact *contact;
+  TpConnection *connection;
+  GList *specs, *l;
+  guint n_rows = 0;
+
+  g_assert (information->details_to_set == NULL);
+
+  contact = empathy_contact_get_tp_contact (information->contact);
+  connection = tp_contact_get_connection (contact);
+
+  specs = tp_connection_get_contact_info_supported_fields (connection);
+  specs = g_list_sort (specs, (GCompareFunc) contact_info_field_spec_cmp);
+  for (l = specs; l != NULL; l = l->next)
+    {
+      TpContactInfoFieldSpec *spec = l->data;
+      TpContactInfoField *field;
+      InfoFieldData *field_data;
+      GList *info, *ll;
+      GStrv value = NULL;
+      GtkWidget *w;
+
+      field_data = find_info_field_data (spec->name);
+      if (field_data == NULL)
+        {
+          DEBUG ("Unhandled ContactInfo field spec: %s", spec->name);
+          continue;
+        }
+
+      /* Search initial value */
+      info = tp_contact_get_contact_info (contact);
+      for (ll = info; ll != NULL; ll = ll->next)
+        {
+          field = ll->data;
+          if (!tp_strdiff (field->field_name, spec->name))
+            {
+              value = field->field_value;
+              break;
+            }
+        }
+
+      field = tp_contact_info_field_new (spec->name, spec->parameters, value);
+      information->details_to_set = g_list_prepend (information->details_to_set,
+          field);
+
+      /* Add Title */
+      w = gtk_label_new (_(field_data->title));
+      gtk_table_attach (GTK_TABLE (information->table_details),
+          w, 0, 1, n_rows, n_rows + 1, GTK_FILL, 0, 0, 0);
+      gtk_misc_set_alignment (GTK_MISC (w), 0, 0.5);
+      gtk_widget_show (w);
+
+      /* Add Value */
+      w = gtk_entry_new ();
+      gtk_entry_set_text (GTK_ENTRY (w),
+          field->field_value[0] ? field->field_value[0] : "");
+      gtk_table_attach_defaults (GTK_TABLE (information->table_details),
+          w, 1, 2, n_rows, n_rows + 1);
+      gtk_widget_show (w);
+
+      g_signal_connect (w, "changed",
+        G_CALLBACK (contact_widget_details_changed_cb), field);
+
+      n_rows++;
+    }
+  g_list_free (specs);
+
+  return n_rows;
+}
+
+static guint
+contact_widget_details_update_show (EmpathyContactWidget *information)
+{
+  TpContact *contact;
+  GList *info, *l;
+  guint n_rows = 0;
+
+  contact = empathy_contact_get_tp_contact (information->contact);
+  info = tp_contact_get_contact_info (contact);
+  info = g_list_sort (info, (GCompareFunc) contact_info_field_cmp);
+  for (l = info; l != NULL; l = l->next)
+    {
+      TpContactInfoField *field = l->data;
+      InfoFieldData *field_data;
+      const gchar *value;
+      GtkWidget *w;
+
+      if (field->field_value == NULL || field->field_value[0] == NULL)
+        continue;
+
+      value = field->field_value[0];
+
+      field_data = find_info_field_data (field->field_name);
+      if (field_data == NULL)
+        {
+          DEBUG ("Unhandled ContactInfo field: %s", field->field_name);
+          continue;
+        }
+
+      /* Add Title */
+      w = gtk_label_new (_(field_data->title));
+      gtk_table_attach (GTK_TABLE (information->table_details),
+          w, 0, 1, n_rows, n_rows + 1, GTK_FILL, 0, 0, 0);
+      gtk_misc_set_alignment (GTK_MISC (w), 0, 0.5);
+      gtk_widget_show (w);
+
+      /* Add Value */
+      w = gtk_label_new (value);
+      if (field_data->linkify)
+        {
+          gchar *markup;
+
+          markup = empathy_add_link_markup (value);
+          gtk_label_set_markup (GTK_LABEL (w), markup);
+          g_free (markup);
+        }
+
+      if ((information->flags & EMPATHY_CONTACT_WIDGET_FOR_TOOLTIP) == 0)
+        gtk_label_set_selectable (GTK_LABEL (w), TRUE);
+
+      gtk_table_attach_defaults (GTK_TABLE (information->table_details),
+          w, 1, 2, n_rows, n_rows + 1);
+      gtk_misc_set_alignment (GTK_MISC (w), 0, 0.5);
+      gtk_widget_show (w);
+
+      n_rows++;
+    }
+  g_list_free (info);
+
+  return n_rows;
+}
+
+static void
+contact_widget_details_notify_cb (EmpathyContactWidget *information)
+{
+  guint n_rows;
+
+  gtk_container_foreach (GTK_CONTAINER (information->table_details),
+      (GtkCallback) gtk_widget_destroy, NULL);
+
+  if ((information->flags & EMPATHY_CONTACT_WIDGET_EDIT_DETAILS) != 0)
+    n_rows = contact_widget_details_update_edit (information);
+  else
+    n_rows = contact_widget_details_update_show (information);
+
+  if (n_rows > 0)
+    {
+      gtk_widget_show (information->vbox_details);
+      gtk_widget_show (information->table_details);
+    }
+  else
+    {
+      gtk_widget_hide (information->vbox_details);
+    }
+
+  gtk_widget_hide (information->hbox_details_requested);
+  gtk_spinner_stop (GTK_SPINNER (information->spinner_details));
+}
+
+static void
+contact_widget_details_request_cb (GObject *object,
+    GAsyncResult *res,
+    gpointer user_data)
+{
+  TpContact *contact = TP_CONTACT (object);
+  EmpathyContactWidget *information = user_data;
+  GError *error = NULL;
+
+  if (!tp_contact_request_contact_info_finish (contact, res, &error))
+    {
+      /* If the request got cancelled it could mean the contact widget is
+       * destroyed, so we should not dereference information */
+      if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+        {
+          g_clear_error (&error);
+          return;
+        }
+
+      gtk_widget_hide (information->vbox_details);
+      g_clear_error (&error);
+    }
+  else
+    {
+      contact_widget_details_notify_cb (information);
+    }
+
+  /* If we are going to edit ContactInfo, we don't want live updates */
+  if ((information->flags & EMPATHY_CONTACT_WIDGET_EDIT_DETAILS) == 0)
+    {
+      g_signal_connect_swapped (contact, "notify::contact-info",
+          G_CALLBACK (contact_widget_details_notify_cb), information);
+    }
+
+  g_object_unref (information->details_cancellable);
+  information->details_cancellable = NULL;
+}
+
+static void
+contact_widget_details_feature_prepared_cb (GObject *object,
+    GAsyncResult *res,
+    gpointer user_data)
+{
+  TpConnection *connection = TP_CONNECTION (object);
+  EmpathyContactWidget *information = user_data;
+  TpContact *contact;
+  TpContactInfoFlags flags;
+
+  if (!tp_proxy_prepare_finish (connection, res, NULL))
+    {
+      gtk_widget_hide (information->vbox_details);
+      return;
+    }
+
+  /* If we want to edit info, but connection does not support that, stop */
+  flags = tp_connection_get_contact_info_flags (connection);
+  if ((flags & TP_CONTACT_INFO_FLAG_CAN_SET) == 0 &&
+      (information->flags & EMPATHY_CONTACT_WIDGET_EDIT_DETAILS) != 0)
+    {
+      gtk_widget_hide (information->vbox_details);
+      return;
+    }
+
+  /* Request the contact's info */
+  gtk_widget_show (information->vbox_details);
+  gtk_widget_show (information->hbox_details_requested);
+  gtk_widget_hide (information->table_details);
+  gtk_spinner_start (GTK_SPINNER (information->spinner_details));
+
+  contact = empathy_contact_get_tp_contact (information->contact);
+  g_assert (information->details_cancellable == NULL);
+  information->details_cancellable = g_cancellable_new ();
+  tp_contact_request_contact_info_async (contact,
+      information->details_cancellable, contact_widget_details_request_cb,
+      information);
 }
 
 static void
 contact_widget_details_update (EmpathyContactWidget *information)
 {
-  /* FIXME: Needs new telepathy spec */
+  TpContact *tp_contact = NULL;
+
+  if ((information->flags & EMPATHY_CONTACT_WIDGET_SHOW_DETAILS) == 0 &&
+      (information->flags & EMPATHY_CONTACT_WIDGET_EDIT_DETAILS) == 0)
+    return;
+
+  gtk_widget_hide (information->vbox_details);
+
+  if (information->contact != NULL)
+    tp_contact = empathy_contact_get_tp_contact (information->contact);
+
+  if (tp_contact != NULL)
+    {
+      GQuark features[] = { TP_CONNECTION_FEATURE_CONTACT_INFO, 0 };
+      TpConnection *connection;
+
+      /* First, make sure the CONTACT_INFO feature is ready on the connection */
+      connection = tp_contact_get_connection (tp_contact);
+      tp_proxy_prepare_async (connection, features,
+          contact_widget_details_feature_prepared_cb, information);
+    }
 }
 
 static void
@@ -183,7 +559,7 @@ contact_widget_cell_toggled (GtkCellRendererToggle *cell,
   GtkListStore *store;
   GtkTreePath *path;
   GtkTreeIter iter;
-  gboolean enabled;
+  gboolean was_enabled;
   gchar *group;
 
   view = GTK_TREE_VIEW (information->treeview_groups);
@@ -194,27 +570,16 @@ contact_widget_cell_toggled (GtkCellRendererToggle *cell,
 
   gtk_tree_model_get_iter (model, &iter, path);
   gtk_tree_model_get (model, &iter,
-      COL_ENABLED, &enabled,
+      COL_ENABLED, &was_enabled,
       COL_NAME, &group,
       -1);
 
-  gtk_list_store_set (store, &iter, COL_ENABLED, !enabled, -1);
+  gtk_list_store_set (store, &iter, COL_ENABLED, !was_enabled, -1);
   gtk_tree_path_free (path);
 
-  if (group)
+  if (group != NULL)
     {
-      if (enabled)
-        {
-          empathy_contact_list_remove_from_group (
-              EMPATHY_CONTACT_LIST (information->manager), information->contact,
-              group);
-        }
-      else
-        {
-          empathy_contact_list_add_to_group (
-              EMPATHY_CONTACT_LIST (information->manager), information->contact,
-              group);
-        }
+      empathy_contact_change_group (information->contact, group, !was_enabled);
       g_free (group);
     }
 }
@@ -434,9 +799,7 @@ contact_widget_button_group_clicked_cb (GtkButton *button,
       COL_ENABLED, TRUE,
       -1);
 
-  empathy_contact_list_add_to_group (
-      EMPATHY_CONTACT_LIST (information->manager), information->contact,
-      group);
+  empathy_contact_change_group (information->contact, group, TRUE);
 }
 
 static void
@@ -714,7 +1077,7 @@ contact_widget_location_update (EmpathyContactWidget *information)
       champlain_view_add_layer (information->map_view, layer);
 
       marker = champlain_marker_new_with_text (
-          empathy_contact_get_name (information->contact), NULL, NULL, NULL);
+          empathy_contact_get_alias (information->contact), NULL, NULL, NULL);
       champlain_base_marker_set_position (CHAMPLAIN_BASE_MARKER (marker), lat, lon);
       clutter_container_add (CLUTTER_CONTAINER (layer), marker, NULL);
 
@@ -872,6 +1235,32 @@ widget_avatar_button_press_event_cb (GtkWidget *widget,
   return FALSE;
 }
 
+static void
+set_avatar_cb (GObject *source,
+    GAsyncResult *res,
+    gpointer user_data)
+{
+  GError *error = NULL;
+
+  if (!tp_account_set_avatar_finish (TP_ACCOUNT (source), res, &error)) {
+      DEBUG ("Failed to set Account.Avatar: %s", error->message);
+      g_error_free (error);
+  }
+}
+
+static void
+set_avatar_on_account (TpAccount *account,
+    const gchar *data,
+    gsize size,
+    const gchar *mime_type)
+{
+  DEBUG ("%s Account.Avatar on %s", size > 0 ? "Set": "Clear",
+      tp_proxy_get_object_path (account));
+
+  tp_account_set_avatar_async (account, (const guchar *) data, size,
+      mime_type, set_avatar_cb, NULL);
+}
+
 static void
 contact_widget_avatar_changed_cb (EmpathyAvatarChooser *chooser,
                                   EmpathyContactWidget *information)
@@ -879,12 +1268,37 @@ contact_widget_avatar_changed_cb (EmpathyAvatarChooser *chooser,
   const gchar *data;
   gsize size;
   const gchar *mime_type;
+  TpAccount *account;
 
   empathy_avatar_chooser_get_image_data (
       EMPATHY_AVATAR_CHOOSER (information->widget_avatar),
       &data, &size, &mime_type);
-  empathy_tp_contact_factory_set_avatar (information->factory,
-      data, size, mime_type);
+
+  account = empathy_contact_get_account (information->contact);
+  set_avatar_on_account (account, data, size, mime_type);
+}
+
+static void
+set_nickname_cb (GObject *source,
+    GAsyncResult *res,
+    gpointer user_data)
+{
+  GError *error = NULL;
+
+  if (!tp_account_set_nickname_finish (TP_ACCOUNT (source), res, &error))
+    {
+      DEBUG ("Failed to set Account.Nickname: %s", error->message);
+      g_error_free (error);
+    }
+}
+
+static void
+set_alias_on_account (TpAccount *account,
+    const gchar *alias)
+{
+  DEBUG ("Set Account.Nickname to %s", alias);
+
+  tp_account_set_nickname_async (account, alias, set_nickname_cb, NULL);
 }
 
 static gboolean
@@ -897,8 +1311,18 @@ contact_widget_entry_alias_focus_event_cb (GtkEditable *editable,
       const gchar *alias;
 
       alias = gtk_entry_get_text (GTK_ENTRY (editable));
-      empathy_tp_contact_factory_set_alias (information->factory,
-          information->contact, alias);
+
+      if (empathy_contact_is_user (information->contact))
+        {
+          TpAccount * account;
+
+          account = empathy_contact_get_account (information->contact);
+          set_alias_on_account (account, alias);
+        }
+      else
+        {
+          empathy_contact_set_alias (information->contact, alias);
+        }
     }
 
   return FALSE;
@@ -908,10 +1332,13 @@ static void
 update_avatar_chooser_account_cb (EmpathyAccountChooser *account_chooser,
                                   EmpathyAvatarChooser *avatar_chooser)
 {
-  TpConnection *connection;
+  TpAccount *account;
 
-  connection = empathy_account_chooser_get_connection (account_chooser);
-  g_object_set (avatar_chooser, "connection", connection, NULL);
+  account = empathy_account_chooser_get_account (account_chooser);
+  if (account == NULL)
+    return;
+
+  empathy_avatar_chooser_set_account (avatar_chooser, account);
 }
 
 static void
@@ -942,10 +1369,10 @@ contact_widget_name_notify_cb (EmpathyContactWidget *information)
 {
   if (GTK_IS_ENTRY (information->widget_alias))
       gtk_entry_set_text (GTK_ENTRY (information->widget_alias),
-          empathy_contact_get_name (information->contact));
+          empathy_contact_get_alias (information->contact));
   else
       gtk_label_set_label (GTK_LABEL (information->widget_alias),
-          empathy_contact_get_name (information->contact));
+          empathy_contact_get_alias (information->contact));
 }
 
 static void
@@ -966,7 +1393,6 @@ contact_widget_presence_notify_cb (EmpathyContactWidget *information)
   gtk_widget_show (information->image_state);
 }
 
-#if HAVE_FAVOURITE_CONTACTS
 static void
 contact_widget_favourites_changed_cb (EmpathyContactManager *manager,
     EmpathyContact *contact,
@@ -979,13 +1405,16 @@ contact_widget_favourites_changed_cb (EmpathyContactManager *manager,
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (
             information->favourite_checkbox), is_favourite);
 }
-#endif
 
 static void
 contact_widget_remove_contact (EmpathyContactWidget *information)
 {
   if (information->contact)
     {
+      TpContact *tp_contact;
+
+      contact_widget_save (information);
+
       g_signal_handlers_disconnect_by_func (information->contact,
           contact_widget_name_notify_cb, information);
       g_signal_handlers_disconnect_by_func (information->contact,
@@ -995,10 +1424,22 @@ contact_widget_remove_contact (EmpathyContactWidget *information)
       g_signal_handlers_disconnect_by_func (information->contact,
           contact_widget_groups_notify_cb, information);
 
+      tp_contact = empathy_contact_get_tp_contact (information->contact);
+      if (tp_contact != NULL)
+        {
+          g_signal_handlers_disconnect_by_func (tp_contact,
+              contact_widget_details_notify_cb, information);
+        }
+
       g_object_unref (information->contact);
-      g_object_unref (information->factory);
       information->contact = NULL;
-      information->factory = NULL;
+    }
+
+  if (information->details_cancellable != NULL)
+    {
+      /* The cancellable will be unreffed and cleared in
+       * contact_widget_details_request_cb */
+      g_cancellable_cancel (information->details_cancellable);
     }
 }
 
@@ -1069,19 +1510,19 @@ contact_widget_contact_update (EmpathyContactWidget *information)
       contact_widget_presence_notify_cb (information);
       contact_widget_avatar_notify_cb (information);
 
-#if HAVE_FAVOURITE_CONTACTS
       if (information->flags & EMPATHY_CONTACT_WIDGET_EDIT_FAVOURITE)
         {
-          gboolean is_favourite;
-
-          is_favourite = empathy_contact_list_is_favourite (
-              EMPATHY_CONTACT_LIST (information->manager),
+          FolksPersona *persona = empathy_contact_get_persona (
               information->contact);
 
-          contact_widget_favourites_changed_cb (information->manager,
-              information->contact, is_favourite, information);
+          if (persona != NULL && FOLKS_IS_FAVOURITE (persona))
+            {
+              gboolean is_favourite = folks_favourite_get_is_favourite (
+                  FOLKS_FAVOURITE (persona));
+              contact_widget_favourites_changed_cb (information->manager,
+                  information->contact, is_favourite, information);
+            }
         }
-#endif
 
       gtk_widget_show (information->label_alias);
       gtk_widget_show (information->widget_alias);
@@ -1106,13 +1547,7 @@ contact_widget_set_contact (EmpathyContactWidget *information,
 
   contact_widget_remove_contact (information);
   if (contact)
-    {
-      TpConnection *connection;
-
-      connection = empathy_contact_get_connection (contact);
-      information->contact = g_object_ref (contact);
-      information->factory = empathy_tp_contact_factory_dup_singleton (connection);
-    }
+    information->contact = g_object_ref (contact);
 
   /* set the selected account to be the account this contact came from */
   if (contact && EMPATHY_IS_ACCOUNT_CHOOSER (information->widget_account)) {
@@ -1130,7 +1565,7 @@ contact_widget_set_contact (EmpathyContactWidget *information,
 }
 
 static void
-contact_widget_got_contact_cb (EmpathyTpContactFactory *factory,
+contact_widget_got_contact_cb (TpConnection *connection,
                                EmpathyContact *contact,
                                const GError *error,
                                gpointer user_data,
@@ -1150,7 +1585,6 @@ contact_widget_got_contact_cb (EmpathyTpContactFactory *factory,
 static void
 contact_widget_change_contact (EmpathyContactWidget *information)
 {
-  EmpathyTpContactFactory *factory;
   TpConnection *connection;
 
   connection = empathy_account_chooser_get_connection (
@@ -1158,7 +1592,6 @@ contact_widget_change_contact (EmpathyContactWidget *information)
   if (!connection)
       return;
 
-  factory = empathy_tp_contact_factory_dup_singleton (connection);
   if (information->flags & EMPATHY_CONTACT_WIDGET_EDIT_ID)
     {
       const gchar *id;
@@ -1166,20 +1599,18 @@ contact_widget_change_contact (EmpathyContactWidget *information)
       id = gtk_entry_get_text (GTK_ENTRY (information->widget_id));
       if (!EMP_STR_EMPTY (id))
         {
-          empathy_tp_contact_factory_get_from_id (factory, id,
+          empathy_tp_contact_factory_get_from_id (connection, id,
               contact_widget_got_contact_cb, information, NULL,
               G_OBJECT (information->vbox_contact_widget));
         }
     }
   else
     {
-      empathy_tp_contact_factory_get_from_handle (factory,
+      empathy_tp_contact_factory_get_from_handle (connection,
           tp_connection_get_self_handle (connection),
           contact_widget_got_contact_cb, information, NULL,
           G_OBJECT (information->vbox_contact_widget));
     }
-
-  g_object_unref (factory);
 }
 
 static gboolean
@@ -1212,27 +1643,18 @@ contact_widget_id_focus_out_cb (GtkWidget *widget,
   return FALSE;
 }
 
-#if HAVE_FAVOURITE_CONTACTS
 static void
 favourite_toggled_cb (GtkToggleButton *button,
     EmpathyContactWidget *information)
 {
-  gboolean active;
+  FolksPersona *persona = empathy_contact_get_persona (information->contact);
 
-  active = gtk_toggle_button_get_active (button);
-
-  if (active)
+  if (persona != NULL && FOLKS_IS_FAVOURITE (persona))
     {
-      empathy_contact_list_add_to_favourites (
-          EMPATHY_CONTACT_LIST (information->manager), information->contact);
-    }
-  else
-    {
-      empathy_contact_list_remove_from_favourites (
-          EMPATHY_CONTACT_LIST (information->manager), information->contact);
+      gboolean active = gtk_toggle_button_get_active (button);
+      folks_favourite_set_is_favourite (FOLKS_FAVOURITE (persona), active);
     }
 }
-#endif
 
 static void
 contact_widget_contact_setup (EmpathyContactWidget *information)
@@ -1372,7 +1794,6 @@ contact_widget_contact_setup (EmpathyContactWidget *information)
   }
   gtk_widget_show (information->widget_alias);
 
-#if HAVE_FAVOURITE_CONTACTS
   /* Favorite */
   if (information->flags & EMPATHY_CONTACT_WIDGET_EDIT_FAVOURITE)
     {
@@ -1391,7 +1812,6 @@ contact_widget_contact_setup (EmpathyContactWidget *information)
 
       gtk_widget_show (information->favourite_checkbox);
     }
-#endif
 }
 
 static void
