@@ -27,6 +27,7 @@
 #include <telepathy-glib/contact.h>
 #include <telepathy-glib/account.h>
 #include <telepathy-logger/entity.h>
+#include <folks/folks.h>
 
 G_BEGIN_DECLS
 
@@ -74,17 +75,21 @@ EmpathyContact * empathy_contact_new (TpContact *tp_contact);
 EmpathyContact * empathy_contact_from_tpl_contact (TpAccount *account,
     TplEntity *tpl_contact);
 EmpathyContact * empathy_contact_new_for_log (TpAccount *account,
-    const gchar *id, const gchar *name, gboolean is_user);
+    const gchar *id, const gchar *alias, gboolean is_user);
 TpContact * empathy_contact_get_tp_contact (EmpathyContact *contact);
 const gchar * empathy_contact_get_id (EmpathyContact *contact);
 void empathy_contact_set_id (EmpathyContact *contact, const gchar *id);
-const gchar * empathy_contact_get_name (EmpathyContact *contact);
-void empathy_contact_set_name (EmpathyContact *contact, const gchar *name);
+const gchar * empathy_contact_get_alias (EmpathyContact *contact);
 void empathy_contact_set_alias (EmpathyContact *contact, const gchar *alias);
+void empathy_contact_change_group (EmpathyContact *contact, const gchar *group,
+    gboolean is_member);
 EmpathyAvatar * empathy_contact_get_avatar (EmpathyContact *contact);
 void empathy_contact_set_avatar (EmpathyContact *contact,
     EmpathyAvatar *avatar);
 TpAccount * empathy_contact_get_account (EmpathyContact *contact);
+FolksPersona * empathy_contact_get_persona (EmpathyContact *contact);
+void empathy_contact_set_persona (EmpathyContact *contact,
+    FolksPersona *persona);
 TpConnection * empathy_contact_get_connection (EmpathyContact *contact);
 TpConnectionPresenceType empathy_contact_get_presence (EmpathyContact *contact);
 void empathy_contact_set_presence (EmpathyContact *contact,
