@@ -101,7 +101,8 @@ gboolean       empathy_tp_chat_can_add_contact (EmpathyTpChat *self);
 void           empathy_tp_chat_leave                (EmpathyTpChat      *chat);
 void           empathy_tp_chat_join                 (EmpathyTpChat      *chat);
 
-gboolean       empathy_tp_chat_is_invited           (EmpathyTpChat      *chat);
+gboolean       empathy_tp_chat_is_invited           (EmpathyTpChat      *chat,
+						     TpHandle *inviter);
 
 G_END_DECLS
 
