@@ -32,6 +32,9 @@
 
 #include <libxml/uri.h>
 
+#include <folks/folks.h>
+#include <folks/folks-telepathy.h>
+
 #include <telepathy-glib/account-manager.h>
 #include <telepathy-glib/connection.h>
 #include <telepathy-glib/channel.h>
@@ -40,10 +43,12 @@
 
 #include "empathy-utils.h"
 #include "empathy-contact-manager.h"
+#include "empathy-individual-manager.h"
 #include "empathy-dispatcher.h"
 #include "empathy-dispatch-operation.h"
 #include "empathy-idle.h"
 #include "empathy-tp-call.h"
+#include "empathy-tp-contact-factory.h"
 
 #include <extensions/extensions.h>
 
@@ -245,8 +250,9 @@ empathy_presence_get_default_message (TpConnectionPresenceType presence)
 		return _("Invisible");
 	case TP_CONNECTION_PRESENCE_TYPE_OFFLINE:
 		return _("Offline");
-	case TP_CONNECTION_PRESENCE_TYPE_UNSET:
 	case TP_CONNECTION_PRESENCE_TYPE_UNKNOWN:
+		return _("Unknown");
+	case TP_CONNECTION_PRESENCE_TYPE_UNSET:
 	case TP_CONNECTION_PRESENCE_TYPE_ERROR:
 		return NULL;
 	}
@@ -452,92 +458,6 @@ empathy_protocol_name_to_display_name (const gchar *proto_name)
   return NULL;
 }
 
-typedef struct {
-    GObject *instance;
-    GObject *user_data;
-    gulong handler_id;
-} WeakHandlerCtx;
-
-static WeakHandlerCtx *
-whc_new (GObject *instance,
-         GObject *user_data)
-{
-  WeakHandlerCtx *ctx = g_slice_new0 (WeakHandlerCtx);
-
-  ctx->instance = instance;
-  ctx->user_data = user_data;
-
-  return ctx;
-}
-
-static void
-whc_free (WeakHandlerCtx *ctx)
-{
-  g_slice_free (WeakHandlerCtx, ctx);
-}
-
-static void user_data_destroyed_cb (gpointer, GObject *);
-
-static void
-instance_destroyed_cb (gpointer ctx_,
-                       GObject *where_the_instance_was)
-{
-  WeakHandlerCtx *ctx = ctx_;
-
-  DEBUG ("instance for %p destroyed; cleaning up", ctx);
-
-  /* No need to disconnect the signal here, the instance has gone away. */
-  g_object_weak_unref (ctx->user_data, user_data_destroyed_cb, ctx);
-  whc_free (ctx);
-}
-
-static void
-user_data_destroyed_cb (gpointer ctx_,
-                        GObject *where_the_user_data_was)
-{
-  WeakHandlerCtx *ctx = ctx_;
-
-  DEBUG ("user_data for %p destroyed; disconnecting", ctx);
-
-  g_signal_handler_disconnect (ctx->instance, ctx->handler_id);
-  g_object_weak_unref (ctx->instance, instance_destroyed_cb, ctx);
-  whc_free (ctx);
-}
-
-/* This function is copied from telepathy-gabble: util.c */
-/**
- * empathy_signal_connect_weak:
- * @instance: the instance to connect to.
- * @detailed_signal: a string of the form "signal-name::detail".
- * @c_handler: the GCallback to connect.
- * @user_data: an object to pass as data to c_handler calls.
- *
- * Connects a #GCallback function to a signal for a particular object, as if
- * with g_signal_connect(). Additionally, arranges for the signal handler to be
- * disconnected if @user_data is destroyed.
- *
- * This is intended to be a convenient way for objects to use themselves as
- * user_data for callbacks without having to explicitly disconnect all the
- * handlers in their finalizers.
- */
-void
-empathy_signal_connect_weak (gpointer instance,
-    const gchar *detailed_signal,
-    GCallback c_handler,
-    GObject *user_data)
-{
-  GObject *instance_obj = G_OBJECT (instance);
-  WeakHandlerCtx *ctx = whc_new (instance_obj, user_data);
-
-  DEBUG ("connecting to %p:%s with context %p", instance, detailed_signal, ctx);
-
-  ctx->handler_id = g_signal_connect (instance, detailed_signal, c_handler,
-      user_data);
-
-  g_object_weak_ref (instance_obj, instance_destroyed_cb, ctx);
-  g_object_weak_ref (user_data, user_data_destroyed_cb, ctx);
-}
-
 /* Note: this function depends on the account manager having its core feature
  * prepared. */
 TpAccount *
@@ -643,3 +563,67 @@ empathy_connect_new_account (TpAccount *account,
         break;
     }
 }
+
+/* Translate Folks' general presence type to the Tp presence type */
+TpConnectionPresenceType
+empathy_folks_presence_type_to_tp (FolksPresenceType type)
+{
+  return (TpConnectionPresenceType) type;
+}
+
+/* Returns TRUE if the given Individual contains a TpContact */
+gboolean
+empathy_folks_individual_contains_contact (FolksIndividual *individual)
+{
+  GList *personas, *l;
+
+  g_return_val_if_fail (FOLKS_IS_INDIVIDUAL (individual), FALSE);
+
+  personas = folks_individual_get_personas (individual);
+  for (l = personas; l != NULL; l = l->next)
+    {
+      if (TPF_IS_PERSONA (l->data))
+        return (tpf_persona_get_contact (TPF_PERSONA (l->data)) != NULL);
+    }
+
+  return FALSE;
+}
+
+/* TODO: this needs to be eliminated (and replaced in some cases with user
+ * prompts) when we break the assumption that FolksIndividuals are 1:1 with
+ * TpContacts */
+
+/* Retrieve the EmpathyContact corresponding to the first TpContact contained
+ * within the given Individual. Note that this is a temporary convenience. See
+ * the TODO above. */
+EmpathyContact *
+empathy_contact_dup_from_folks_individual (FolksIndividual *individual)
+{
+  GList *personas, *l;
+  EmpathyContact *contact = NULL;
+
+  g_return_val_if_fail (FOLKS_IS_INDIVIDUAL (individual), NULL);
+
+  personas = folks_individual_get_personas (individual);
+  for (l = personas; (l != NULL) && (contact == NULL); l = l->next)
+    {
+      TpfPersona *persona = l->data;
+
+      if (TPF_IS_PERSONA (persona))
+        {
+          TpContact *tp_contact;
+
+          tp_contact = tpf_persona_get_contact (persona);
+          contact = empathy_contact_dup_from_tp_contact (tp_contact);
+        }
+    }
+
+  return contact;
+}
+
+TpChannelGroupChangeReason
+tp_chanel_group_change_reason_from_folks_groups_change_reason (
+    FolksGroupsChangeReason reason)
+{
+  return (TpChannelGroupChangeReason) reason;
+}
