@@ -1281,7 +1281,7 @@ chat_window_show_or_update_notification (EmpathyChatWindow *window,
 	}
 
 	sender = empathy_message_get_sender (message);
-	header = empathy_contact_get_name (sender);
+	header = empathy_contact_get_alias (sender);
 	body = empathy_message_get_body (message);
 	escaped = g_markup_escape_text (body, -1);
 	has_x_canonical_append = empathy_notify_manager_has_capability (
@@ -1461,7 +1461,7 @@ chat_window_detach_hook (GtkNotebook *source,
 
 static void
 chat_window_page_switched_cb (GtkNotebook      *notebook,
-			      GtkNotebookPage  *page,
+			      gpointer          ignore, /* see note below */
 			      gint	        page_num,
 			      EmpathyChatWindow *window)
 {
@@ -1473,6 +1473,9 @@ chat_window_page_switched_cb (GtkNotebook      *notebook,
 
 	priv = GET_PRIV (window);
 
+	/* N.B. in GTK+ 3 child is passed as the first argument to the signal,
+	 * but we can't use that while trying to retain GTK+ 2.x compatibility.
+	 */
 	child = gtk_notebook_get_nth_page (notebook, page_num);
 	chat = EMPATHY_CHAT (child);
 
