@@ -26,6 +26,7 @@
 #include <string.h>
 
 #include <glib.h>
+#include <glib/gstdio.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
@@ -44,16 +45,10 @@
 #include <telepathy-glib/connection-manager.h>
 #include <telepathy-glib/interfaces.h>
 
-#ifdef ENABLE_TPL
 #include <telepathy-logger/log-manager.h>
-#include <telepathy-logger/log-store-empathy.h>
-#else
 
-#include <libempathy/empathy-log-manager.h>
-#endif /* ENABLE_TPL */
 #include <libempathy/empathy-idle.h>
 #include <libempathy/empathy-utils.h>
-#include <libempathy/empathy-call-factory.h>
 #include <libempathy/empathy-chatroom-manager.h>
 #include <libempathy/empathy-account-settings.h>
 #include <libempathy/empathy-connectivity.h>
@@ -61,21 +56,17 @@
 #include <libempathy/empathy-dispatcher.h>
 #include <libempathy/empathy-dispatch-operation.h>
 #include <libempathy/empathy-ft-factory.h>
+#include <libempathy/empathy-gsettings.h>
 #include <libempathy/empathy-tp-chat.h>
-#include <libempathy/empathy-tp-call.h>
 
-#include <libempathy-gtk/empathy-conf.h>
 #include <libempathy-gtk/empathy-ui-utils.h>
 #include <libempathy-gtk/empathy-location-manager.h>
 
 #include "empathy-main-window.h"
-#include "empathy-import-mc4-accounts.h"
 #include "empathy-accounts-common.h"
 #include "empathy-accounts-dialog.h"
 #include "empathy-chat-manager.h"
 #include "empathy-status-icon.h"
-#include "empathy-call-window.h"
-#include "empathy-chat-window.h"
 #include "empathy-ft-manager.h"
 
 #include "extensions/extensions.h"
@@ -83,8 +74,6 @@
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
 #include <libempathy/empathy-debug.h>
 
-#include <gst/gst.h>
-
 static gboolean start_hidden = FALSE;
 static gboolean no_connect = FALSE;
 
@@ -101,58 +90,7 @@ dispatch_cb (EmpathyDispatcher *dispatcher,
 
   channel_type = empathy_dispatch_operation_get_channel_type_id (operation);
 
-  if (channel_type == TP_IFACE_QUARK_CHANNEL_TYPE_TEXT)
-    {
-      EmpathyTpChat *tp_chat;
-      EmpathyChat   *chat = NULL;
-      const gchar   *id;
-
-      tp_chat = EMPATHY_TP_CHAT
-        (empathy_dispatch_operation_get_channel_wrapper (operation));
-
-      id = empathy_tp_chat_get_id (tp_chat);
-      if (!EMP_STR_EMPTY (id))
-        {
-          TpConnection *connection;
-          TpAccount *account;
-
-          connection = empathy_tp_chat_get_connection (tp_chat);
-          account = empathy_get_account_for_connection (connection);
-          chat = empathy_chat_window_find_chat (account, id);
-        }
-
-      if (chat)
-        {
-          empathy_chat_set_tp_chat (chat, tp_chat);
-        }
-      else
-        {
-          chat = empathy_chat_new (tp_chat);
-          /* empathy_chat_new returns a floating reference as EmpathyChat is
-           * a GtkWidget. This reference will be taken by a container
-           * (a GtkNotebook) when we'll call empathy_chat_window_present_chat */
-        }
-
-      empathy_chat_window_present_chat (chat,
-          empathy_dispatch_operation_get_user_action_time (operation));
-
-      if (empathy_tp_chat_is_invited (tp_chat))
-        {
-          /* We have been invited to the room. Add ourself as member as this
-           * channel has been approved. */
-          empathy_tp_chat_join (tp_chat);
-        }
-
-      empathy_dispatch_operation_claim (operation);
-    }
-  else if (channel_type == TP_IFACE_QUARK_CHANNEL_TYPE_STREAMED_MEDIA)
-    {
-      EmpathyCallFactory *factory;
-
-      factory = empathy_call_factory_get ();
-      empathy_call_factory_claim_channel (factory, operation);
-    }
-  else if (channel_type == TP_IFACE_QUARK_CHANNEL_TYPE_FILE_TRANSFER)
+  if (channel_type == TP_IFACE_QUARK_CHANNEL_TYPE_FILE_TRANSFER)
     {
       EmpathyFTFactory *factory;
 
@@ -168,17 +106,14 @@ dispatch_cb (EmpathyDispatcher *dispatcher,
 }
 
 static void
-use_conn_notify_cb (EmpathyConf *conf,
+use_conn_notify_cb (GSettings *gsettings,
     const gchar *key,
     gpointer     user_data)
 {
   EmpathyConnectivity *connectivity = user_data;
-  gboolean     use_conn;
 
-  if (empathy_conf_get_bool (conf, key, &use_conn))
-    {
-      empathy_connectivity_set_use_conn (connectivity, use_conn);
-    }
+  empathy_connectivity_set_use_conn (connectivity,
+      g_settings_get_boolean (gsettings, key));
 }
 
 static void
@@ -332,18 +267,6 @@ new_ft_handler_cb (EmpathyFTFactory *factory,
   g_object_unref (handler);
 }
 
-static void
-new_call_handler_cb (EmpathyCallFactory *factory,
-    EmpathyCallHandler *handler,
-    gboolean outgoing,
-    gpointer user_data)
-{
-  EmpathyCallWindow *window;
-
-  window = empathy_call_window_new (handler);
-  gtk_widget_show (GTK_WIDGET (window));
-}
-
 static void
 account_manager_ready_cb (GObject *source_object,
     GAsyncResult *result,
@@ -353,8 +276,8 @@ account_manager_ready_cb (GObject *source_object,
   GError *error = NULL;
   EmpathyIdle *idle;
   EmpathyConnectivity *connectivity;
-  gboolean autoconnect = TRUE;
   TpConnectionPresenceType presence;
+  GSettings *gsettings = g_settings_new (EMPATHY_PREFS_SCHEMA);
 
   if (!tp_account_manager_prepare_finish (manager, result, &error))
     {
@@ -370,23 +293,21 @@ account_manager_ready_cb (GObject *source_object,
   presence = tp_account_manager_get_most_available_presence (manager, NULL,
       NULL);
 
-  empathy_conf_get_bool (empathy_conf_get (),
-      EMPATHY_PREFS_AUTOCONNECT, &autoconnect);
-  if (autoconnect && !no_connect &&
+  if (g_settings_get_boolean (gsettings, EMPATHY_PREFS_AUTOCONNECT) &&
+      !no_connect &&
       tp_connection_presence_type_cmp_availability
           (presence, TP_CONNECTION_PRESENCE_TYPE_OFFLINE)
             <= 0)
       /* if current state is Offline, then put it online */
       empathy_idle_set_state (idle, TP_CONNECTION_PRESENCE_TYPE_AVAILABLE);
 
-  /* Pop up the accounts dialog if it's needed (either when we don't have any
-   * accounts yet or when we haven't imported mc4 accounts yet */
-  if (!empathy_accounts_has_accounts (manager)
-      || !empathy_import_mc4_has_imported ())
+  /* Pop up the accounts dialog if we don't have any account */
+  if (!empathy_accounts_has_accounts (manager))
     show_accounts_ui (gdk_screen_get_default (), TRUE);
 
   g_object_unref (idle);
   g_object_unref (connectivity);
+  g_object_unref (gsettings);
 }
 
 static EmpathyDispatcher *
@@ -398,39 +319,12 @@ setup_dispatcher (void)
     const gchar *channeltype;
     TpHandleType handletype;
   } types[] = {
-    /* Text channels with handle types none, contact and room */
-    { TP_IFACE_CHANNEL_TYPE_TEXT, TP_HANDLE_TYPE_NONE  },
-    { TP_IFACE_CHANNEL_TYPE_TEXT, TP_HANDLE_TYPE_CONTACT  },
-    { TP_IFACE_CHANNEL_TYPE_TEXT, TP_HANDLE_TYPE_ROOM  },
     /* file transfer to contacts */
     { TP_IFACE_CHANNEL_TYPE_FILE_TRANSFER, TP_HANDLE_TYPE_CONTACT  },
-    /* stream media to contacts */
-    { TP_IFACE_CHANNEL_TYPE_STREAMED_MEDIA, TP_HANDLE_TYPE_CONTACT  },
-    /* roomlists */
-    { TP_IFACE_CHANNEL_TYPE_ROOM_LIST, TP_HANDLE_TYPE_NONE },
   };
-  gchar *capabilities[] = {
-    "org.freedesktop.Telepathy.Channel.Interface.MediaSignalling/ice-udp",
-    "org.freedesktop.Telepathy.Channel.Interface.MediaSignalling/gtalk-p2p",
-    NULL };
   GHashTable *asv;
   guint i;
 
-  /* Setup the basic Client.Handler that matches our client filter */
-  filters = g_ptr_array_new ();
-  asv = tp_asv_new (
-        TP_IFACE_CHANNEL ".ChannelType", G_TYPE_STRING,
-           TP_IFACE_CHANNEL_TYPE_TEXT,
-        TP_IFACE_CHANNEL ".TargetHandleType", G_TYPE_INT,
-            TP_HANDLE_TYPE_CONTACT,
-        NULL);
-  g_ptr_array_add (filters, asv);
-
-  d = empathy_dispatcher_new (PACKAGE_NAME, filters, NULL);
-
-  g_ptr_array_foreach (filters, (GFunc) g_hash_table_destroy, NULL);
-  g_ptr_array_free (filters, TRUE);
-
   /* Setup the an extended Client.Handler that matches everything we can do */
   filters = g_ptr_array_new ();
   for (i = 0 ; i < G_N_ELEMENTS (types); i++)
@@ -443,29 +337,7 @@ setup_dispatcher (void)
       g_ptr_array_add (filters, asv);
     }
 
-  asv = tp_asv_new (
-        TP_IFACE_CHANNEL ".ChannelType",
-          G_TYPE_STRING, TP_IFACE_CHANNEL_TYPE_STREAMED_MEDIA,
-        TP_IFACE_CHANNEL ".TargetHandleType",
-          G_TYPE_INT, TP_HANDLE_TYPE_CONTACT,
-        TP_IFACE_CHANNEL_TYPE_STREAMED_MEDIA ".InitialAudio",
-          G_TYPE_BOOLEAN, TRUE,
-        NULL);
-  g_ptr_array_add (filters, asv);
-
-  asv = tp_asv_new (
-        TP_IFACE_CHANNEL ".ChannelType",
-          G_TYPE_STRING, TP_IFACE_CHANNEL_TYPE_STREAMED_MEDIA,
-        TP_IFACE_CHANNEL ".TargetHandleType",
-          G_TYPE_INT, TP_HANDLE_TYPE_CONTACT,
-        TP_IFACE_CHANNEL_TYPE_STREAMED_MEDIA ".InitialVideo",
-          G_TYPE_BOOLEAN, TRUE,
-        NULL);
-  g_ptr_array_add (filters, asv);
-
-
-  empathy_dispatcher_add_handler (d, PACKAGE_NAME"MoreThanMeetsTheEye",
-    filters, capabilities);
+  d = empathy_dispatcher_new (PACKAGE_NAME"MoreThanMeetsTheEye", filters, NULL);
 
   g_ptr_array_foreach (filters, (GFunc) g_hash_table_destroy, NULL);
   g_ptr_array_free (filters, TRUE);
@@ -489,8 +361,7 @@ account_status_changed_cb (TpAccount *account,
     return;
 
   empathy_dispatcher_join_muc (conn,
-      empathy_chatroom_get_room (room), EMPATHY_DISPATCHER_NON_USER_ACTION,
-      NULL, NULL);
+      empathy_chatroom_get_room (room), EMPATHY_DISPATCHER_NON_USER_ACTION);
 }
 
 static void
@@ -539,7 +410,7 @@ account_manager_chatroom_ready_cb (GObject *source_object,
             {
               empathy_dispatcher_join_muc (conn,
                   empathy_chatroom_get_room (room),
-                  EMPATHY_DISPATCHER_NON_USER_ACTION, NULL, NULL);
+                  EMPATHY_DISPATCHER_NON_USER_ACTION);
             }
         }
 
@@ -561,15 +432,14 @@ chatroom_manager_ready_cb (EmpathyChatroomManager *chatroom_manager,
 }
 
 static void
-empathy_idle_set_auto_away_cb (EmpathyConf *conf,
+empathy_idle_set_auto_away_cb (GSettings *gsettings,
 				const gchar *key,
 				gpointer user_data)
 {
-	gboolean autoaway;
 	EmpathyIdle *idle = user_data;
 
-	empathy_conf_get_bool (conf, key, &autoaway);
-	empathy_idle_set_auto_away (idle, autoaway);
+	empathy_idle_set_auto_away (idle,
+      g_settings_get_boolean (gsettings, key));
 }
 
 int
@@ -581,13 +451,8 @@ main (int argc, char *argv[])
   EmpathyStatusIcon *icon;
   EmpathyDispatcher *dispatcher;
   TpAccountManager *account_manager;
-#ifdef ENABLE_TPL
   TplLogManager *log_manager;
-#else
-  EmpathyLogManager *log_manager;
-#endif /* ENABLE_TPL */
   EmpathyChatroomManager *chatroom_manager;
-  EmpathyCallFactory *call_factory;
   EmpathyFTFactory  *ft_factory;
   GtkWidget *window;
   EmpathyIdle *idle;
@@ -600,6 +465,7 @@ main (int argc, char *argv[])
 #ifdef ENABLE_DEBUG
   TpDebugSender *debug_sender;
 #endif
+  GSettings *gsettings;
 
   GOptionContext *optcontext;
   GOptionEntry options[] = {
@@ -622,7 +488,6 @@ main (int argc, char *argv[])
   empathy_init ();
 
   optcontext = g_option_context_new (N_("- Empathy IM Client"));
-  g_option_context_add_group (optcontext, gst_init_get_option_group ());
   g_option_context_add_group (optcontext, gtk_get_option_group (TRUE));
 #if HAVE_LIBCHAMPLAIN
   g_option_context_add_group (optcontext, clutter_get_option_group ());
@@ -640,7 +505,6 @@ main (int argc, char *argv[])
 
   empathy_gtk_init ();
   g_set_application_name (_(PACKAGE_NAME));
-  g_setenv ("PULSE_PROP_media.role", "phone", TRUE);
 
   gtk_window_set_default_icon_name ("empathy");
   textdomain (GETTEXT_PACKAGE);
@@ -666,22 +530,22 @@ main (int argc, char *argv[])
   /* Setting up Idle */
   idle = empathy_idle_dup_singleton ();
 
-  empathy_conf_get_bool (empathy_conf_get (),
-      EMPATHY_PREFS_AUTOAWAY, &autoaway);
+  gsettings = g_settings_new (EMPATHY_PREFS_SCHEMA);
+  autoaway = g_settings_get_boolean (gsettings, EMPATHY_PREFS_AUTOAWAY);
 
-  empathy_conf_notify_add (empathy_conf_get (),
-			   EMPATHY_PREFS_AUTOAWAY,
-			   empathy_idle_set_auto_away_cb,
-			   idle);
+  g_signal_connect (gsettings,
+      "changed::" EMPATHY_PREFS_AUTOAWAY,
+      G_CALLBACK (empathy_idle_set_auto_away_cb), idle);
 
   empathy_idle_set_auto_away (idle, autoaway);
 
   /* Setting up Connectivity */
   connectivity = empathy_connectivity_dup_singleton ();
-  use_conn_notify_cb (empathy_conf_get (), EMPATHY_PREFS_USE_CONN,
+  use_conn_notify_cb (gsettings, EMPATHY_PREFS_USE_CONN,
       connectivity);
-  empathy_conf_notify_add (empathy_conf_get (), EMPATHY_PREFS_USE_CONN,
-      use_conn_notify_cb, connectivity);
+  g_signal_connect (gsettings,
+      "changed::" EMPATHY_PREFS_USE_CONN,
+      G_CALLBACK (use_conn_notify_cb), connectivity);
 
   /* account management */
   account_manager = tp_account_manager_dup ();
@@ -695,7 +559,8 @@ main (int argc, char *argv[])
   migrate_config_to_xdg_dir ();
 
   /* Setting up UI */
-  window = empathy_main_window_show ();
+  window = empathy_main_window_dup ();
+  gtk_widget_show (window);
   icon = empathy_status_icon_new (GTK_WINDOW (window), start_hidden);
 
   /* Chat manager */
@@ -705,15 +570,9 @@ main (int argc, char *argv[])
       G_CALLBACK (unique_app_message_cb), window);
 
   /* Logging */
-#ifdef ENABLE_TPL
   log_manager = tpl_log_manager_dup_singleton ();
-#else
-  log_manager = empathy_log_manager_dup_singleton ();
-  empathy_log_manager_observe (log_manager, dispatcher);
-#endif
 
   chatroom_manager = empathy_chatroom_manager_dup_singleton (NULL);
-  empathy_chatroom_manager_observe (chatroom_manager, dispatcher);
 
   g_object_get (chatroom_manager, "ready", &chatroom_manager_ready, NULL);
   if (!chatroom_manager_ready)
@@ -726,10 +585,6 @@ main (int argc, char *argv[])
       chatroom_manager_ready_cb (chatroom_manager, NULL, account_manager);
     }
 
-  /* Create the call factory */
-  call_factory = empathy_call_factory_initialise ();
-  g_signal_connect (G_OBJECT (call_factory), "new-call-handler",
-      G_CALLBACK (new_call_handler_cb), NULL);
   /* Create the FT factory */
   ft_factory = empathy_ft_factory_dup_singleton ();
   g_signal_connect (ft_factory, "new-ft-handler",
@@ -763,6 +618,8 @@ main (int argc, char *argv[])
 #endif
   g_object_unref (ft_factory);
   g_object_unref (unique_app);
+  g_object_unref (gsettings);
+  gtk_widget_destroy (window);
 
   notify_uninit ();
   xmlCleanupParser ();
